<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link      
 * @since      1.0.0
 *
 * @package    SSBDP
 * @subpackage SSBDP/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    SSBDP
 * @subpackage SSBDP/admin
 * @author     Stefanjm
 */
class SSBDP_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $SSBDP    The ID of this plugin.
	 */
	private $SSBDP;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $SSBDP       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($SSBDP, $version)
	{

		$this->SSBDP = $SSBDP;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in SSBDP_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The SSBDP_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->SSBDP, plugin_dir_url(__FILE__) . 'css/SSBDP-admin.css', array(), $this->version, 'all');

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in SSBDP_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The SSBDP_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->SSBDP, plugin_dir_url(__FILE__) . 'js/SSBDP-admin.js', array('jquery'), $this->version, false);

	}

	public function addEditorToSimpleProduct()
	{
		global $product_object;
		$linked_product_ids = $product_object->get_meta(SSBDP_META_KEY);

		if (!is_array($linked_product_ids)) {
			$linked_product_ids = array($linked_product_ids);
		}

		// create the editor
		$this->createLinkedProductEditor($linked_product_ids, SSBDP_META_KEY);
	}

	public function addEditorToProductWithVariations($loop, $variation_data, $variation)
	{
		$linked_product_ids = get_post_meta($variation->ID, SSBDP_META_KEY, true);

		if (!is_array($linked_product_ids)) {
			$linked_product_ids = array($linked_product_ids);
		}
		// create the editor
		$this->createLinkedProductEditor($linked_product_ids, SSBDP_META_KEY . "[$variation->ID]");
	}


	private function createLinkedProductEditor($linked_product_ids, $form_name)
	{
		?>
		<div class="options_group">
			<p class="form-field">
				<label
					for="ssbdp_linked_products"><?php esc_html_e('Linked products for stock status sharing', 'sync-products-stock-status'); ?></label>
				<select class="wc-product-search" multiple="multiple" style="width: 50%;" name="<?php echo esc_attr($form_name) ?>[]"
					data-placeholder="<?php esc_attr_e('Search for a product&hellip;', 'sync-products-stock-status'); ?>">
					<?php
					if (!empty($linked_product_ids)) {
						foreach ($linked_product_ids as $linked_product_id) {
							$product = wc_get_product($linked_product_id);
							if (is_object($product)) {
								echo '<option value="' . esc_attr($linked_product_id) . '"' . selected(in_array($linked_product_id, $linked_product_ids), true, false) . '>' . esc_html(wp_strip_all_tags($product->get_formatted_name())) . '</option>';
							}
						}
					}
					?>
				</select>
				<span class="description"><?php esc_html_e('These are products that are linked.', 'sync-products-stock-status'); ?></span>
			</p>
			<?php wp_nonce_field('ssbdp_save_linked_products', 'ssbdp_nonce'); ?>
		</div>
		<?php
	}

	public function saveLinkedProductsSimple($post_id)
	{
		if (isset($_POST[SSBDP_META_KEY])) {

			// Nonce verification
			if (!isset($_POST['ssbdp_nonce']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['ssbdp_nonce'])), 'ssbdp_save_linked_products')) {
				wp_die('Sorry, your nonce was not correct.'); // Or handle the error appropriately, e.g., display an admin notice
				return; // Important: Stop further processing if nonce is invalid
			}

			$product = wc_get_product(intval($post_id));
			$new_linked_product_ids = array_map('sanitize_text_field', wp_unslash($_POST[SSBDP_META_KEY]));

			// Get existing linked products
			$existing_linked_product_ids = $product->get_meta(SSBDP_META_KEY, true);
			if (!is_array($existing_linked_product_ids)) {
				$existing_linked_product_ids = array();
			}

			// Update linked products for the current product
			$product->update_meta_data(SSBDP_META_KEY, $new_linked_product_ids);
			$product->save_meta_data();

			// Remove links from products that are no longer linked
			$this->removeUnlinkedProducts($existing_linked_product_ids, $new_linked_product_ids, $post_id, SSBDP_META_KEY);

			// Add links to newly linked products
			$this->addNewLinkedProducts($existing_linked_product_ids, $new_linked_product_ids, $post_id, SSBDP_META_KEY);
		} else {
			// Nonce verification
			if (isset($_POST['ssbdp_nonce_delete']) && (!isset($_POST['ssbdp_nonce_delete']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['ssbdp_nonce_delete'])), 'ssbdp_delete_linked_products'))) {
				wp_die('Sorry, your nonce was not correct for deletion.');
				return;
			}
			// delete the meta data
			$this->deleteLinkedProducts($post_id, SSBDP_META_KEY);
		}
	}

	public function saveLinkedProductsForVariations($variation_id)
	{
		if (isset($_POST[SSBDP_META_KEY][$variation_id])) {

			// Nonce verification
			if (!isset($_POST['ssbdp_nonce']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['ssbdp_nonce'])), 'ssbdp_save_linked_products')) {
				wp_die('Sorry, your nonce was not correct.'); // Or handle the error appropriately, e.g., display an admin notice
				return; // Important: Stop further processing if nonce is invalid
			}

			$variation = wc_get_product($variation_id);
			if ($variation && $variation->is_type('variation')) {
				$new_linked_product_ids = array_map('sanitize_text_field', wp_unslash($_POST[SSBDP_META_KEY][$variation_id]));

				// Get existing linked products
				$existing_linked_product_ids = $variation->get_meta(SSBDP_META_KEY, true);
				if (!is_array($existing_linked_product_ids)) {
					$existing_linked_product_ids = array();
				}

				// Update linked products for the current variation
				$variation->update_meta_data(SSBDP_META_KEY, $new_linked_product_ids);
				$variation->save_meta_data();

				// Remove links from products that are no longer linked
				$this->removeUnlinkedProducts($existing_linked_product_ids, $new_linked_product_ids, $variation_id, SSBDP_META_KEY);

				// Add links to newly linked products
				$this->addNewLinkedProducts($existing_linked_product_ids, $new_linked_product_ids, $variation_id, SSBDP_META_KEY);
			}
		} else {
			// delete the meta data
			$this->deleteLinkedProducts($variation_id, SSBDP_META_KEY);
		}
	}

	private function removeUnlinkedProducts($existing_linked_product_ids, $new_linked_product_ids, $current_product_id, $meta_key)
	{
		foreach ($existing_linked_product_ids as $linked_product_id) {
			if (!in_array($linked_product_id, $new_linked_product_ids)) {
				$linked_product = wc_get_product($linked_product_id);
				if ($linked_product) {
					$linked_product_links = $linked_product->get_meta($meta_key, true);
					if (is_array($linked_product_links)) {
						$linked_product_links = array_diff($linked_product_links, array($current_product_id));
						$linked_product->update_meta_data($meta_key, $linked_product_links);
						$linked_product->save_meta_data();
					}
				}
			}
		}
	}
	private function addNewLinkedProducts($existing_linked_product_ids, $new_linked_product_ids, $current_product_id, $meta_key)
	{
		foreach ($new_linked_product_ids as $linked_product_id) {
			if (!in_array($linked_product_id, $existing_linked_product_ids)) {
				$linked_product = wc_get_product($linked_product_id);
				if ($linked_product) {
					$linked_product_links = $linked_product->get_meta($meta_key, true);
					if (!is_array($linked_product_links)) {
						$linked_product_links = array();
					}
					if (!in_array($current_product_id, $linked_product_links)) {
						$linked_product_links[] = $current_product_id;
						$linked_product->update_meta_data($meta_key, $linked_product_links);
						$linked_product->save_meta_data();
					}
				}
			}
		}
	}

	private function deleteLinkedProducts($current_product_id, $meta_key)
	{
		$product = wc_get_product(intval($current_product_id));
		$existing_linked_product_ids = $product->get_meta($meta_key, true);
		if (is_array($existing_linked_product_ids)) {
			foreach ($existing_linked_product_ids as $linked_product_id) {
				$linked_product = wc_get_product($linked_product_id);
				if ($linked_product) {
					$linked_product_links = $linked_product->get_meta($meta_key, true);
					if (is_array($linked_product_links)) {
						$linked_product_links = array_diff($linked_product_links, array($current_product_id));
						$linked_product->update_meta_data($meta_key, $linked_product_links);
						$linked_product->save_meta_data();
					}
				}
			}
		}
		delete_post_meta($current_product_id, $meta_key);
	}

	public function onProductStockChange($product_id)
	{
		// also change the stock of linked products
		$product = wc_get_product($product_id);
		$linked_product_ids = $product->get_meta(SSBDP_META_KEY);
		if (is_array($linked_product_ids)) {
			$this->setProductStockQuantity($product, $linked_product_ids);
		}
	}

	private function setProductStockQuantity($mainProduct, $linked_product_ids)
	{
		foreach ($linked_product_ids as $linked_product_id) {
			$linked_product = wc_get_product($linked_product_id);
			if ($linked_product) {
				$linked_product->set_stock_status($mainProduct->get_stock_status());
				$linked_product->save();
			}
		}
	}
}


