<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       
 * @since      1.0.0
 *
 * @package    SSBDP
 * @subpackage SSBDP/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    SSBDP
 * @subpackage SSBDP/public
 * @author     Stefanjm
 */
class SSBDP_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $SSBDP    The ID of this plugin.
	 */
	private $SSBDP;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $SSBDP       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $SSBDP, $version ) {

		$this->SSBDP = $SSBDP;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in SSBDP_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The SSBDP_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->SSBDP, plugin_dir_url( __FILE__ ) . 'css/SSBDP-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in SSBDP_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The SSBDP_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->SSBDP, plugin_dir_url( __FILE__ ) . 'js/SSBDP-public.js', array( 'jquery' ), $this->version, false );

	}

}
