<?php

/**
 * Fired when the plugin is uninstalled.
 *
 * When populating this file, consider the following flow
 * of control:
 *
 * - This method should be static
 * - Check if the $_REQUEST content actually is the plugin name
 * - Run an admin referrer check to make sure it goes through authentication
 * - Verify the output of $_GET makes sense
 * - Repeat with other user roles. Best directly by using the links/query string parameters.
 * - Repeat things for multisite. Once for a single site in the network, once sitewide.
 *
 * This file may be updated more in future version of the Boilerplate; however, this is the
 * general skeleton and outline for how the file should work.
 *
 * For more information, see the following discussion:
 * https://github.com/tommcfarlin/WordPress-Plugin-Boilerplate/pull/123#issuecomment-28541913
 *
 * @link       
 * @since      1.0.0
 *
 * @package    SSBDP
 */

// If uninstall not called from WordPress, then exit.
if ( ! defined( 'WP_UNINSTALL_PLUGIN' ) ) {
	exit;
}

require_once plugin_dir_path(__FILE__) . 'constants.php';

class SSBDP_Uninstall_Steps {

	public static function SSBDP_uninstall() {
		self::SSBDP_removeAllPluginUsedPostMeta();
	}


	/**
	 * Remove SSBDP post meta entries
	 * @return void
	 */
	private static function SSBDP_removeAllPluginUsedPostMeta()
	{
		// Access constants from SSBDP_Admin class
		$meta_key = SSBDP_META_KEY;

		// remove meta data
		self::SSBDP_removeMetaByKey($meta_key);

	}

	public static function SSBDP_removeMetaByKey($meta_key)
	{
		// Get all posts that have your plugin's meta key
		$posts = get_posts(array(
			'post_type' => array('product', 'product_variation'),
			'meta_query' => array(
				array(
					'key' => $meta_key,
					'compare' => 'EXISTS', // Check if the meta key exists
				),
			),
			'posts_per_page' => -1, // Get all posts
			'fields' => 'ids', // Only get post IDs for performance
		));

		// Delete the meta for each post
		foreach ($posts as $post_id) {
			delete_post_meta($post_id, $meta_key);
		}
	}
}

SSBDP_Uninstall_Steps:: SSBDP_uninstall();